# Exceptions for the class Word.
nounificationExceptions = {
    'be' : 'identity',
    'have' : 'possession',
    'do' : 'process',
    'bear' : 'birth',
    'live' : 'residence',
    'direct' : 'director',
    'impress' : 'impression',
    'fix' : 'repair',
    'know' : 'knowledge',
    'invent' : 'inventor'
}
